# Example Package

[GetHub Project](https://github.com/DrSudoSaeed/)

Random string production library.

To use, install the library according to the instructions!

**Follow the steps below to use:**

```

**Default length: 5**


from Rnd_str.main import random_str

a = random_str(5)
print(a)

```